function [tarray zarray] = Midpoint(rhsname,tspan,z0,p)
%Midpoint method of solving any number of 1st order ODEs
znew = z0;              % get things started
ntimes = length(tspan); % Figure out how many times to evaluate
n_odes=length(z0);      % Figure out how many 1st order ODEs

zarray = zeros(ntimes,n_odes);   % initialize z
zarray(1,:) = znew'; 

%The main loop
for i = 2:ntimes
 t    = tspan(i-1);   % the  'old' time  for this time step
 z    = znew;         % the new old z is the old new z
 h    = tspan(i) - tspan(i-1);   % size of full time step
 
 %Midpoint method is just the next 4 lines
 %rhsname is a text string saying the name of the function which
 %contains the ODEs to solve. The function whose name is stored
 %in rhsname is evaluated using t,z and p.
 zdottemp =        feval(rhsname,t,z,p);
 znewtemp =  z   + zdottemp*h/2;   % take a temporary half step
 zdot     =        feval(rhsname,t+h/2,znewtemp,p); %evaluate at midpoint
 znew     =  z   + zdot    *h;     % Take full step using best guess at zdot
 
 zarray(i,:) = znew';  % store the new values as a row of the array
end
 
tarray=tspan;
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


