function earthmoonmain
% Mass moves on plane with various forces
% See TAM 2030 lectures from 2/28/2013
clear all
%time span
 t0 = 0;    h = .005;  t1 = 40;  
 n = floor((t1-t0)/h);         % number of time steps
 tspan = linspace(t0,t1,n);    % set of all times

%Initial conditions: 2 comps of position and 2 comps of velocity 
 rA0 = [.5 0]';  rB0 = [-5 0]';   vA0 = [ 0 1]';  vB0 = [ 0 -1]';
 z0 = [rA0;rB0;vA0;vB0]; % the eight initial conditions

%Parameters for all problems here
 p.mA = 1; p.mB = 1;   
 p.k = 2;  p.L0 = .5; p.c= .1;  % spring & dashpot parameters
 p.G = 1;    % big G, universal gravity constant

 
%The ODE solution is all done on the next line.
%Can use either  "Euler" or "Midpoint".
%Can use ODEs in rhs1 or in rhs2
[tarray zarray] = Euler('rhs2',tspan, z0, p);

%Unpack the positions for plotting
xAarray = zarray(:,1); yAarray = zarray(:,2);
xBarray = zarray(:,3); yBarray = zarray(:,4);

figure(1)  %PLOT THE TRAJECTORIES
clf  %clear figure
axes('fontsize',15)
plot(xAarray,yAarray, 'b-',xBarray,yBarray, 'r--' )
xlabel('x of both masses. A is dotted red, B is blue.','fontsize',17); 
ylabel('y of both masses','fontsize',17);
title('Two planets go around each other, or whatever','fontsize', 20)
axis('equal')  % so circles come out round

shg   % Show graph (bring graphics window up front)
end





